@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
   -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
@@ -28,10 +28,10 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include <stdint.h>
 #include <libHX.h>
-#if !defined(_LIBHX_H) || _LIBHX_H < 20041109
-#    error --------------------------------------------
-#    error You need a newer version of libHX (20041109)
-#    error --------------------------------------------
+#if !defined(_LIBHX_H) || _LIBHX_H < 20050105
+#    error -----------------------------------------------------
+#    error You need a newer version of libHX (at least 20050105)
+#    error -----------------------------------------------------
 #endif
 
 #define RECEIVE_FULL(fd, ptr, sz) \
