@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/replay.c - Realtime TTY log analyzer
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
   -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
@@ -91,6 +91,7 @@ int main(int argc, const char **argv) {
     const char *auto_stdin[] = {"/dev/stdin", NULL};
     int i;
 
+    load_locale(*argv);
     if(!get_options(&argc, &argv)) { return EXIT_FAILURE; }
 
     fprintf(stderr, "> ttyreplay " TTYRPLD_VERSION "\n");
@@ -429,8 +430,8 @@ static int get_options(int *argc, const char ***argv) {
          _("Speed factor (default: 1.0)"), NULL},
         {NULL, 'T', POPT_ARG_NONE, &Opt.nodelay, 'T',
          _("No delays (useful for text file grepping)"), NULL},
-        {NULL, 'f', POPT_ARG_NONE, NULL, 'f',
-         _("Catch-up follow mode (play file, switch to live feed on EOF)"), NULL},
+        {NULL, 'f', POPT_ARG_NONE, NULL, 'f', _("Catch-up follow mode (play"
+         " file, switch to live feed on EOF)"), NULL},
         {NULL, 'j', POPT_ARG_LONG, &Opt.skval, 'j',
          _("Skip the given number of EVT_WRITE packets"), NULL},
         {NULL, 'm', POPT_ARG_LONG, &Opt.maxdelay, 'm',
