@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/rpld.c - User space daemon (filtering, etc.)
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
   -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
@@ -102,10 +102,7 @@ int main(int argc, const char **argv) {
     pthread_t infod_id;
     int fd;
 
-    setlocale(LC_ALL, "");
-    bindtextdomain("ttyrpld", "/home/jengelha/f/ttyrpld/locale");
-    textdomain("ttyrpld");
-
+    load_locale(*argv);
     umask(umask(S_IWUSR | S_IWOTH) | S_IRUGO | S_IRWXG | S_IRWXO); // 0022,0477
 
     /* Yep, the config file is what is needed by all three
@@ -256,7 +253,8 @@ static int packet_preprox(struct mem_packet *packet) {
             Stats.out += packet->size;
             break;
         default:
-            notify(LOG_WARNING, _("Unknown packet type 0x%02X\n"), packet->event);
+            notify(LOG_WARNING, _("Unknown packet type 0x%02X\n"),
+             packet->event);
             return 0;
     }
 
@@ -352,8 +350,8 @@ static int log_open(struct tty *tty) {
     if(!Opt.dolog) {
         snprintf(buf, MAXFNLEN, "/dev/null");
     } else if(check_parent_directory(buf) <= 0) {
-        notify(LOG_ERR, _("Directory permission denied: It won't be possible to"
-         " write to the file %s, expect warnings.\n"), buf);
+        notify(LOG_ERR, _("Directory permission denied: It won't be possible"
+         " to write to the file %s, expect warnings.\n"), buf);
     }
     if((tty->fd = open(buf, O_WRONLY | O_CREAT | O_APPEND, S_IWUSR)) < 0) {
         notify(LOG_ERR, _("Could not open %s: %s\n"), buf, strerror(errno));
@@ -408,8 +406,9 @@ static int init_device(const char *in_devs) {
             new_dev = NULL;
             perror(_("dynamic_find(): Could not open RPL device"));
             if(se == EBUSY) {
-                fprintf(stderr, _("\t" "The RPL device can only be opened once,"
-                 "\n\t" "there is probably an instance of rpld running!\n"));
+                fprintf(stderr, _("\t" "The RPL device can only be opened"
+                 " once,\n\t" "there is probably an instance of rpld"
+                 " running!\n"));
             }
         } else if(GOpt.verbose) {
             printf(_("Successfully opened RPL device\n"));
@@ -563,9 +562,8 @@ static void sighandler_int(int s) {
 
 static void sighandler_alrm(int s) {
     fprintf(stderr, "\r\e[2K" "IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu (%llu/%llu)"
-      " I: %zu  B: %zu",
-      Stats.init, Stats.open, Stats.close, Stats.deinit, Stats.read, Stats.write, Stats.in,
-      Stats.out, Stats.ioctl, Stats.badpack
+      " I: %zu  B: %zu", Stats.init, Stats.open, Stats.close, Stats.deinit,
+      Stats.read, Stats.write, Stats.in, Stats.out, Stats.ioctl, Stats.badpack
     );
     if(GOpt.verbose) { alarm(1); }
     return;
